aboutsummaryrefslogtreecommitdiff
path: root/src/include/taler_exchange_service.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/taler_exchange_service.h')
-rw-r--r--src/include/taler_exchange_service.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/include/taler_exchange_service.h b/src/include/taler_exchange_service.h
index 7f3436cce..36a23598e 100644
--- a/src/include/taler_exchange_service.h
+++ b/src/include/taler_exchange_service.h
@@ -1709,9 +1709,9 @@ struct TALER_EXCHANGE_TransferData
struct TALER_ExchangeSignatureP exchange_sig;
/**
* hash of the wire transfer address the transfer went to
*/
- struct TALER_MerchantWireHash h_wire;
+ struct TALER_PaytoHash h_wire;
/**
* time when the exchange claims to have performed the wire transfer
@@ -1709,9 +1709,9 @@ struct TALER_EXCHANGE_TransferData
struct TALER_ExchangeSignatureP exchange_sig;
/**
- * hash of the wire transfer address the transfer went to
+ * hash of the payto:// URI the transfer went to
*/